@@ -14,16 +14,6 @@ plot.MFA=function (x, axes = c(1, 2), choix = c("ind","var","group","axes","freq
     choix <- match.arg(choix,c("ind","var","group","axes","freq"))
 	invisible <- match.arg(invisible,c("none","ind", "ind.sup", "quanti","quanti.sup","quali","row", "row.sup","col", "col.sup"),several.ok=TRUE)
     if ("none"%in%invisible) invisible = NULL
-    if (is.null(palette)) 
-        palette(c("black", "red", "green3", "blue", "cyan", "magenta", 
-            "darkgray", "darkgoldenrod", "darkgreen", "violet", 
-            "turquoise", "orange", "lightpink", "lavender", "yellow", 
-            "lightgreen", "lightgrey", "lightblue", "darkkhaki", 
-            "darkmagenta", "darkolivegreen", "lightcyan", "darkorange", 
-            "darkorchid", "darkred", "darksalmon", "darkseagreen", 
-            "darkslateblue", "darkslategray", "darkslategrey", 
-            "darkturquoise", "darkviolet", "lightgray", "lightsalmon", 
-            "lightyellow", "maroon"))
     lab.x <- paste("Dim ",axes[1]," (",format(res.mfa$eig[axes[1],2],nsmall=2,digits=2),"%)",sep="")
     lab.y <- paste("Dim ",axes[2]," (",format(res.mfa$eig[axes[2],2],nsmall=2,digits=2),"%)",sep="")
     group <- res.mfa$call$group
@@ -39,6 +29,7 @@ plot.MFA=function (x, axes = c(1, 2), choix = c("ind","var","group","axes","freq
     }
     if (choix == "axes") {
         if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
+        if (is.null(palette)) palette(c("black", "red", "green3", "blue", "cyan", "magenta","darkgray", "darkgoldenrod", "darkgreen", "violet","turquoise", "orange", "lightpink", "lavender", "yellow","lightgreen", "lightgrey", "lightblue", "darkkhaki","darkmagenta", "darkolivegreen", "lightcyan", "darkorange","darkorchid", "darkred", "darksalmon", "darkseagreen","darkslateblue", "darkslategray", "darkslategrey","darkturquoise", "darkviolet", "lightgray", "lightsalmon","lightyellow", "maroon"))
         if (is.null(title)) title <- "Partial axes"
         plot(0, 0, xlab = lab.x, ylab = lab.y, xlim = c(-1.1, 1.1), ylim = c(-1.1, 1.1), col = "white", asp = 1, main = title,...)
         x.cercle <- seq(-1, 1, by = 0.01)
@@ -116,6 +107,7 @@ plot.MFA=function (x, axes = c(1, 2), choix = c("ind","var","group","axes","freq
         if (habillage == "group") col.hab <- (2:(length(group) + 1))
 
 	  if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
+      if (is.null(palette)) palette(c("black", "red", "green3", "blue", "cyan", "magenta","darkgray", "darkgoldenrod", "darkgreen", "violet","turquoise", "orange", "lightpink", "lavender", "yellow","lightgreen", "lightgrey", "lightblue", "darkkhaki","darkmagenta", "darkolivegreen", "lightcyan", "darkorange","darkorchid", "darkred", "darksalmon", "darkseagreen","darkslateblue", "darkslategray", "darkslategrey","darkturquoise", "darkviolet", "lightgray", "lightsalmon","lightyellow", "maroon"))
 	  coo <- labe <- coll <- ipch <- fonte <- NULL
 	  if (is.null(xlim)) xlim <- c(0,1)
 	  if (is.null(ylim)) ylim <- c(0,1)
@@ -146,6 +138,7 @@ plot.MFA=function (x, axes = c(1, 2), choix = c("ind","var","group","axes","freq
 	}
     if (choix == "var") {
         if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
+        if (is.null(palette)) palette(c("black", "red", "green3", "blue", "cyan", "magenta","darkgray", "darkgoldenrod", "darkgreen", "violet","turquoise", "orange", "lightpink", "lavender", "yellow","lightgreen", "lightgrey", "lightblue", "darkkhaki","darkmagenta", "darkolivegreen", "lightcyan", "darkorange","darkorchid", "darkred", "darksalmon", "darkseagreen","darkslateblue", "darkslategray", "darkslategrey","darkturquoise", "darkviolet", "lightgray", "lightsalmon","lightyellow", "maroon"))
         test.invisible <- vector(length = 2)
         if (!is.null(invisible)) {
             test.invisible[1] <- match("quanti", invisible)
@@ -298,6 +291,7 @@ plot.MFA=function (x, axes = c(1, 2), choix = c("ind","var","group","axes","freq
     }
 	if (choix=="freq"){
       if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
+      if (is.null(palette)) palette(c("black", "red", "green3", "blue", "cyan", "magenta","darkgray", "darkgoldenrod", "darkgreen", "violet","turquoise", "orange", "lightpink", "lavender", "yellow","lightgreen", "lightgrey", "lightblue", "darkkhaki","darkmagenta", "darkolivegreen", "lightcyan", "darkorange","darkorchid", "darkred", "darksalmon", "darkseagreen","darkslateblue", "darkslategray", "darkslategrey","darkturquoise", "darkviolet", "lightgray", "lightsalmon","lightyellow", "maroon"))
       col.row = "black"
 	  col.row.sup = "grey60"
       coord.col <- res.mfa$freq$coord[, axes, drop = FALSE]
@@ -810,6 +804,7 @@ plot.MFA=function (x, axes = c(1, 2), choix = c("ind","var","group","axes","freq
             col.ind <- col.ind.sup <- col.quali.sup <- col.quali <- col.ellipse <- col.ellipse.par <- rep("black", 
                 nb.ind * (nbre.grpe + 1))
         if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY")))  dev.new(width = min(14, max(8, 8 * (xmax - xmin)/(ymax - ymin))), height = 8)
+        if (is.null(palette)) palette(c("black", "red", "green3", "blue", "cyan", "magenta","darkgray", "darkgoldenrod", "darkgreen", "violet","turquoise", "orange", "lightpink", "lavender", "yellow","lightgreen", "lightgrey", "lightblue", "darkkhaki","darkmagenta", "darkolivegreen", "lightcyan", "darkorange","darkorchid", "darkred", "darksalmon", "darkseagreen","darkslateblue", "darkslategray", "darkslategrey","darkturquoise", "darkviolet", "lightgray", "lightsalmon","lightyellow", "maroon"))
         if (is.null(title))  title <- "Individual factor map"
         plot(0, 0, main = title, xlab = lab.x, ylab = lab.y, xlim = xlim, ylim = ylim, col = "white", asp = 1, ...)
         abline(v = 0, lty = 2, ...)
